<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>プラグインの追加</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>検索:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>ウィジェットへ追加</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(一度に実行できるインスタンスは 1 つだけです)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>パネルの設定</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>パネル</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>パネルの設定</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="109"/>
        <location filename="../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> ピクセル</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>アイコンのサイズ:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>長さ:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;負のピクセル値を設定すると、スクリーンの最大領域からその値を差し引いた長さになります。&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;例: スクリーンのサイズが 1000 ピクセルである場合に -100 ピクセルを設定すると、パネルの長さは 900 ピクセルになります。&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>ピクセル</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>位置寄せと場所</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="262"/>
        <location filename="../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>0 はアニメーションしません</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="288"/>
        <location filename="../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> ミリ秒</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>アニメーションの長さ:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="173"/>
        <source>Rows:</source>
        <translation>行数:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="219"/>
        <location filename="../config/configpanelwidget.cpp" line="211"/>
        <source>Left</source>
        <translation>左寄せ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="224"/>
        <location filename="../config/configpanelwidget.cpp" line="212"/>
        <location filename="../config/configpanelwidget.cpp" line="218"/>
        <source>Center</source>
        <translation>中央</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="229"/>
        <location filename="../config/configpanelwidget.cpp" line="213"/>
        <source>Right</source>
        <translation>右寄せ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>自動的に隠す(&amp;U)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="301"/>
        <location filename="../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>0 は遅延しません</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>表示の遅延:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation>隠れたパネルの細い余白を見えるようにする</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="337"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>最大化したウィンドウをパネルの後ろに配置しません</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="340"/>
        <source>Reserve space on display</source>
        <translation>表示用スペースを確保する</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="356"/>
        <source>Custom styling</source>
        <translation>スタイルのカスタマイズ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="377"/>
        <source>Font color:</source>
        <translation>フォントの色:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="417"/>
        <source>Background color:</source>
        <translation>背景色:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="456"/>
        <source>Background opacity:</source>
        <translation>背景の不透明度:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="488"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;パネルの透明化にはコンポジターが必要です。&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="516"/>
        <source>Background image:</source>
        <translation>背景の画像:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="568"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation>パネルに個別のテーマを指定できない
ウィジェットのスタイルのための部分的な回避策です。

次の設定を無効にすることもできます。

LXQt 設定 - 外観 →
アイコンテーマ →
ウィジェットのスタイル（パレット）に基づいてアイコンを色付けする</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="578"/>
        <source>Override icon &amp;theme</source>
        <translation>アイコンのテーマを上書きする(&amp;T)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="593"/>
        <source>Icon theme for panels:</source>
        <translation>パネルのアイコンテーマ:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>位置寄せ:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>場所:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="177"/>
        <source>Top of desktop</source>
        <translation>デスクトップの上</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="178"/>
        <source>Left of desktop</source>
        <translation>デスクトップの左</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="179"/>
        <source>Right of desktop</source>
        <translation>デスクトップの右</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="180"/>
        <source>Bottom of desktop</source>
        <translation>デスクトップの下</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="189"/>
        <source>Top of desktop %1</source>
        <translation>モニター %1 の上</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="190"/>
        <source>Left of desktop %1</source>
        <translation>モニター %1 の左</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="191"/>
        <source>Right of desktop %1</source>
        <translation>モニター %1 の右</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="192"/>
        <source>Bottom of desktop %1</source>
        <translation>モニター %1 の下</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="217"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="219"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="439"/>
        <location filename="../config/configpanelwidget.cpp" line="455"/>
        <source>Pick color</source>
        <translation>色の選択</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="473"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>画像 (*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="473"/>
        <source>Pick image</source>
        <translation>画像の選択</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>プラグインの設定</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>注意: このページでの変更は[リセット]ボタンで初期化されません。</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>上に移動</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>下に移動</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1130"/>
        <location filename="../lxqtpanel.cpp" line="1156"/>
        <source>Panel</source>
        <translation>パネル</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1159"/>
        <source>Configure Panel</source>
        <translation>パネルの設定</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1164"/>
        <source>Manage Widgets</source>
        <translation>ウィジェットの管理</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1170"/>
        <source>Add New Panel</source>
        <translation>新しいパネルの追加</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1177"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>パネルの削除</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1182"/>
        <source>Lock This Panel</source>
        <translation>パネルのロック</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1338"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>パネルの削除</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1339"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>パネルを削除すると、元に戻せません。
このパネルを削除しますか？</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="436"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>【%1】の設定</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="441"/>
        <source>Move &quot;%1&quot;</source>
        <translation>【%1】の移動</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="449"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>【%1】の削除</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>代替の設定ファイルを使用する。</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>ファイルの設定</translation>
    </message>
</context>
</TS>
